********************
API Reference
********************

Oct2Py
======
.. module:: oct2py
.. autoclass:: Oct2Py
   :members:

Utils
=====

.. autoclass:: Oct2PyError

.. autofunction:: get_log

.. autoclass:: Struct

.. autofunction:: kill_octave
